@@ -100,6 +100,43 @@ class EpsieAdaptiveNormal(epsie_proposals.AdaptiveNormal):
                                           boundary_arg_name='prior_widths')
 
 
+class EpsieATAdaptiveNormal(epsie_proposals.ATAdaptiveNormal):
+    """Adds ``from_config`` method to epsie's ATAdaptiveProposal."""
+
+    @classmethod
+    def from_config(cls, cp, section, tag):
+        """Loads a proposal from a config file.
+
+        This calls :py:func:`epsie_from_config` with ``cls`` set to
+        :py:class:`epsie.proposals.AdaptiveProposal` and ``with_boundaries``
+        set to False. See that function for details on options that can be
+        read.
+
+        Example::
+
+            [jump_proposal-mchrip+q]
+            name = adaptive_proposal
+            diagonal =
+
+        Parameters
+        ----------
+        cp : WorkflowConfigParser instance
+            Config file to read from.
+        section : str
+            The name of the section to look in.
+        tag : str
+            :py:const:`pycbc.VARARGS_DELIM` separated list of parameter names
+            to create proposals for.
+
+        Returns
+        -------
+        :py:class:`epsie.proposals.AdaptiveProposal`:
+            An adaptive proposal for use with ``epsie`` samplers.
+        """
+        return epsie_at_adaptive_from_config(cls, cp, section, tag,
+                                             with_boundaries=False)
+
+
 def epsie_from_config(cls, cp, section, tag, with_boundaries=False):
     r"""Generic function for loading epsie proposals from a config file.
 
@@ -153,6 +190,9 @@ def epsie_from_config(cls, cp, section, tag, with_boundaries=False):
     if with_boundaries:
         boundaries = get_param_boundaries(params, opts)
         args['boundaries'] = boundaries
+    if 'discrete' in cls.name.split('_'):
+        args.update({'successive':
+                     get_epsie_discrete_successive_settings(params, opts)})
     # if there are any options left, assume they are for setting the variance
     if opts:
         cov = get_variance(params, opts)
@@ -235,6 +275,9 @@ def epsie_adaptive_from_config(cls, cp, section, tag, with_boundaries=True,
     # get the bounds
     if with_boundaries:
         args[boundary_arg_name] = get_param_boundaries(params, opts)
+    if 'discrete' in cls.name.split('_'):
+        args.update({'successive':
+                     get_epsie_discrete_successive_settings(params, opts)})
     # get the adaptation parameters
     args.update(get_epsie_adaptation_settings(opts))
     # if there are any other options, assume they are for setting the
@@ -250,6 +293,87 @@ def epsie_adaptive_from_config(cls, cp, section, tag, with_boundaries=True,
     return cls(**args)
 
 
+def epsie_at_adaptive_from_config(cls, cp, section, tag,
+                                  with_boundaries=False):
+    """Generic function for loading AT Adaptive Normal proposals from a config
+    file.
+
+    The section that is read should have the format ``[{section}-{tag}]``,
+    where ``{tag}`` is a :py:const:`pycbc.VARARGS_DELIM` separated list
+    of the parameters to create the jump proposal for.
+
+    Options that are read:
+
+    * name : str
+        Required. Must match the name of the proposal.
+    * adaptation-duration : int
+        Sets the ``adaptation_duration``. If not provided will use the class's
+        default.
+    * diagonal : bool, optional
+        Determines whether only to adapt the variance. If True will only train
+        the diagonal elements.
+    * componentwise : bool, optional
+        Whether to include a componentwise scaling of the parameters.
+        By default set to False. Componentwise scaling `ndim` times more
+        expensive than global scaling.
+    * min-{param} : float
+    * max-{param} : float
+        The bounds on each parameter. Required if ``with_boundaries`` is set to
+        True, in which case bounds must be provided for every parameter.
+    * start-iteration : int
+        Optional. Sets the ``start_iteration``. If not provided, will use
+        the class's default.
+    * target-rate : float
+        Optional. Sets the ``target_rate``. If not provided, will use
+        the class's default.
+
+    Parameters
+    ----------
+    cls : epsie.proposals.BaseProposal
+        The epsie proposal class to initialize. The class should have
+        :py:class:`epsie.proposals.normal.AdaptiveSupport`.
+    cp : WorkflowConfigParser instance
+        Config file to read from.
+    section : str
+        The name of the section to look in.
+    tag : str
+        :py:const:`pycbc.VARARGS_DELIM` separated list of parameter names
+        to create proposals for.
+    with_boundaries : bool, optional
+        Try to load boundaries from the section and pass a ``boundaries``
+        argument to the class's initialization. Default is True.
+
+    Returns
+    -------
+    cls :
+        The class initialized with the options read from the config file.
+    """
+    # check that the name matches
+    assert cp.get_opt_tag(section, "name", tag) == cls.name, (
+        "name in specified section must match mine")
+    params, opts = load_opts(cp, section, tag, skip=['name'])
+    args = {'parameters': params}
+    # get the bounds
+    if with_boundaries:
+        args['boundaries'] = get_param_boundaries(params, opts)
+    if 'discrete' in cls.name.split('_'):
+        args.update({'successive':
+                     get_epsie_discrete_successive_settings(params, opts)})
+    # get the adaptation parameters
+    args.update(get_epsie_adaptation_settings(opts, cls.name))
+    # bounded and angular adaptive proposals support diagonal-only
+    diagonal = opts.pop('diagonal', None)
+    if not any(p in cls.name.split('_') for p in ['bounded', 'angular']):
+        args.update({'diagonal': diagonal is not None})
+    componentwise = opts.pop('componentwise', None)
+    if componentwise is not None:
+        args.update({'componentwise': True})
+    if opts:
+        raise ValueError("unrecognized options {}"
+                         .format(', '.join(opts.keys())))
+    return cls(**args)
+
+
 def load_opts(cp, section, tag, skip=None):
     """Loads config options for jump proposals.
 
@@ -352,7 +476,7 @@ def get_param_boundaries(params, opts):
     return boundaries
 
 
-def get_epsie_adaptation_settings(opts):
+def get_epsie_adaptation_settings(opts, name=None):
     """Get settings for Epsie adaptive proposals from a config file.
 
     This requires that ``adaptation_duration`` is in the given dictionary.
@@ -365,6 +489,8 @@ def get_epsie_adaptation_settings(opts):
     opts : dict
         Dictionary of option -> value that was loaded from a config file
         section.
+    name : str (optional)
+        Proposal name
 
     Returns
     -------
@@ -374,8 +500,13 @@ def get_epsie_adaptation_settings(opts):
     args = {}
     adaptation_duration = opts.pop('adaptation_duration', None)
     if adaptation_duration is None:
-        raise ValueError("No adaptation_duration specified")
-    args['adaptation_duration'] = int(adaptation_duration)
+        if name is not None:
+            if all(p in name.split('_') for p in ['at', 'adaptive']):
+                args.update({'adaptation_duration': None})
+        else:
+            raise ValueError("No adaptation_duration specified")
+    else:
+        args.update({'adaptation_duration': int(adaptation_duration)})
     # optional args
     adaptation_decay = opts.pop('adaptation_decay', None)
     if adaptation_decay is not None:
@@ -387,3 +518,38 @@ def get_epsie_adaptation_settings(opts):
     if target_rate is not None:
         args.update({'target_rate': float(target_rate)})
     return args
+
+
+def get_epsie_discrete_successive_settings(params, opts):
+    """Get settings for Epsie successive discrete proposal successive jumps
+    from a config file.
+
+    If ``successive`` is not defined for a parameter then assumes successive
+    jumps are not allowed (i.e. jumps from an integer to the same integer).
+    Arguments will be popped from the given dictionary.
+
+    Example::
+        [jump_proposal-k+n]
+        name = discrete
+        successive-k =
+
+    This example sets successive jumps for ``k`` but does not do so for ``n``.
+
+    Parameters
+    ----------
+    params : list of str
+        List of parameter names to get the successive option for.
+    opts : dict
+        Dictionary of option -> value that was loaded from a config file
+        section.
+
+    Returns
+    -------
+    dict :
+        Dictionary of parameter names -> bools
+    """
+    successive = {}
+    for param in params:
+        successive.update(
+            {param: opts.pop('successive_{}'.format(param), None) is not None})
+    return successive
